summaryrefslogtreecommitdiff
path: root/test/core/model/DocumentTest.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/core/model/DocumentTest.cpp')
-rw-r--r--test/core/model/DocumentTest.cpp12
1 files changed, 10 insertions, 2 deletions
diff --git a/test/core/model/DocumentTest.cpp b/test/core/model/DocumentTest.cpp
index 36e7c02..dd883a4 100644
--- a/test/core/model/DocumentTest.cpp
+++ b/test/core/model/DocumentTest.cpp
@@ -20,12 +20,20 @@
#include <core/model/Document.hpp>
+#include "ModelTestUtils.hpp"
+
namespace ousia {
namespace model {
+
+
TEST(Document, testDocumentConstruction)
{
- // Start by constructing the domain.
- //TODO: IMPLEMENT
+ // Construct Manager
+ Manager mgr{1};
+ // Get the domain.
+ Rooted<Domain> domain = constructBookDomain(mgr);
+
+ // TODO: IMPLEMENT
ASSERT_TRUE(true);
}
}